==> bhaiapi-0.1.38.tar.gz: bhaiapi-0.1.38/setup.py <==
# Copyright 2023 parkminwoo, MIT License

import re
from setuptools import find_packages
from setuptools import setup


def get_version():
    filename = "bhaiapi/__init__.py"
    with open(filename) as f:
        match = re.search(r"""^__version__ = ['"]([^'"]*)['"]""", f.read(), re.M)
    if not match:
        raise RuntimeError("{} doesn't contain __version__".format(filename))
    version = match.groups()[0]
    return version


def get_long_description():
    with open("README.md", encoding="UTF-8") as f:
        long_description = f.read()
        return long_description


version = get_version()

setup(
    name="bhaiapi",
    version="0.1.38",
    author="daniel park",
    author_email="parkminwoo1991@gmail.com",
    description="The python package that returns Response of Google bhai through API.",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    url="https://github.com/dsdanielpark/bhai-API",
    packages=find_packages(exclude=[]),
    python_requires=">=3.6",
    install_requires=["httpx[http2]>=0.20.0", 
                      "requests",
                      "deep_translator",
                      "colorama",
                      "google-cloud-translate",
                      "browser_cookie3",
                      "langdetect",
                      ],
    keywords="Python, API, bhai, Google bard, Large Language Model, Chatbot API, Google API, Chatbot",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Science/Research",
        "Natural Language :: English",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    entry_points={"console_scripts": ["bhaiapi=bhaiapi.main:main"]},
)

==> bhaiapi-0.1.40.tar.gz: bhaiapi-0.1.40/setup.py <==
# Copyright 2023 parkminwoo, MIT License

import re
from setuptools import find_packages
from setuptools import setup


def get_version():
    filename = "bhaiapi/__init__.py"
    with open(filename) as f:
        match = re.search(r"""^__version__ = ['"]([^'"]*)['"]""", f.read(), re.M)
    if not match:
        raise RuntimeError("{} doesn't contain __version__".format(filename))
    version = match.groups()[0]
    return version


def get_long_description():
    with open("README.md", encoding="UTF-8") as f:
        long_description = f.read()
        return long_description


version = get_version()

setup(
    name="bhaiapi",
    version="0.1.40",
    author="Hk4crprasad",
    author_email="hotahara12@gmail.com",
    description="The python package that returns Response of Google bhai through API.",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    url="https://github.com/hk4crprasad/bhaiapi",
    packages=find_packages(exclude=[]),
    python_requires=">=3.6",
    install_requires=["httpx[http2]>=0.20.0", 
                      "requests",
                      "deep_translator",
                      "colorama",
                      "google-cloud-translate",
                      "browser_cookie3",
                      "langdetect",
                      "speechrecognition",
                      "youtube-search-python",
                      "gtts",
                      "python-dotenv",
                      "keyboard",
                      "rich"
                      ],
    keywords="Python, API, bhai, Google bard, Large Language Model, Chatbot API, Google API, Chatbot",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Science/Research",
        "Natural Language :: English",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    entry_points={"console_scripts": ["bhaiapi=bhaiapi.main:main"]},
)
